@@ -11,7 +11,7 @@
 #
 # Run this script followed by the path of instdir/share/registry/
 # i.e.: ./convertfilters.py /path/to/source/core/instdir/share/registry
-# 
+#
 # Requires Python 3.6 or greater.
 
 import os
@@ -32,12 +32,12 @@ if not os.path.exists(registry_dir):
     print(f"{registry_dir} does not exist. Make sure you have built the core repo before running this script")
     sys.exit(1)
 
-modules = ["writer.xcd","calc.xcd","impress.xcd","draw.xcd","math.xcd","base.xcd","graphicfilter.xcd"]
+modules = ["writer.xcd","calc.xcd","impress.xcd","draw.xcd","math.xcd","base.xcd","graphicfilter.xcd","pdfimport.xcd","xsltfilter.xcd"]
 
 def gen_id(apiname):
-    '''This function accepts module name and an API Name of the filter, and then generate 
+    '''This function accepts module name and an API Name of the filter, and then generate
     a unique ID. API Names are used since they are unique within the page.
-    
+
     Do not use random numbers or sequence-count numbers here since it will cause all words to be "fuzzy" in PO files
     when the xhp file is regenerated.
     '''
@@ -45,7 +45,7 @@ def gen_id(apiname):
     apiname = apiname.replace("(", "_")
     apiname = apiname.replace(")", "_")
     apiname = apiname.replace("/", "_")
-    
+
     return apiname
 
 output = '''<?xml version="1.0" encoding="UTF-8"?>
@@ -60,13 +60,13 @@ output = '''<?xml version="1.0" encoding="UTF-8"?>
 -->
 <meta>
     <topic id="convertfilters" indexer="include" status="PUBLISH">
-        <title id="tit" xml-lang="en-US">File Conversion Filters Tables</title>
+        <title id="tit">File Conversion Filters Tables</title>
         <filename>/text/shared/guide/convertfilters.xhp</filename>
     </topic>
 </meta>
 <body>
 <section id="convertfilters01">
-    <bookmark xml-lang="en-US" branch="index" id="bm_id541554406270299">
+    <bookmark  branch="index" id="bm_id541554406270299">
         <bookmark_value>filters;document conversion</bookmark_value>
         <bookmark_value>document conversion;filters</bookmark_value>
         <bookmark_value>convert-to;filters</bookmark_value>
@@ -74,22 +74,28 @@ output = '''<?xml version="1.0" encoding="UTF-8"?>
         <bookmark_value>module file filters</bookmark_value>
     </bookmark>
     <h1 id="hd_id771554399002497">
-        <link href="text/shared/guide/convertfilters.xhp" name="conversion filter names">File Conversion Filter Names</link>
+        <variable id="convertfilters_h1"><link href="text/shared/guide/convertfilters.xhp">File Conversion Filter Names</link></variable>
     </h1>
-    <paragraph id="par_id581554399002498" role="paragraph" xml-lang="en-US">
-        <variable id="variable name">
-            <ahelp hid=".">Tables with filter names for command line document conversion.</ahelp>
+    <paragraph id="par_id581554399002498" role="paragraph" >
+        <variable id="commandline_intro">
+            <ahelp hid=".">Tables with filter names for <link href="text/shared/guide/start_parameters.xhp">command line</link> document conversion.</ahelp>
         </variable>
     </paragraph>
 </section>
+<h2 id="hd_id531633524464103">Usage</h2>
+<paragraph role="paragraph" id="par_id801633524474460">Filter names are used when importing and exporting files in alien formats and converting files formats through the <link href="text/shared/guide/start_parameters.xhp">command line</link>.</paragraph>
+<paragraph role="paragraph" id="par_id314959p" localize="false" ><emph>soffice --convert-to OutputFileExtension[:OutputFilterName[:OutputFilterParams[,param]]] [--outdir output_dir]</emph></paragraph>
+<embed href="text/shared/guide/start_parameters.xhp#convertto"/>
+<paragraph role="tablecontent" id="par_id314959o" localize="false" ><emph>soffice --infilter=&quot;InputFilterName[:InputFilterParams[,param]]&quot;</emph></paragraph>
+<paragraph role="paragraph" id="par_id501550934647297" localize="false"><input>--infilter="Text (encoded):UTF8,LF,Liberation Mono,en-US"</input>.</paragraph>
 '''
 
 output += '''
 <paragraph role="paragraph" id="par_id00tablehead">
     <ahelp hid="." visibility="hidden">
-        <variable visibility="hidden" id="filtername">Filter Name</variable>
-        <variable visibility="hidden" id="apiname">API Name</variable>
-        <variable visibility="hidden" id="mediatype">Media Type (Extension)</variable>
+        <variable visibility="hidden" id="filtername">Displayed Filter Name</variable>
+        <variable visibility="hidden" id="apiname">API Name (OutputFilterName / InputFilterName)</variable>
+        <variable visibility="hidden" id="mediatype">Media Type (OutputFileExtension)</variable>
     </ahelp>
 </paragraph>
 '''
@@ -107,7 +113,7 @@ for module in modules:
     for filter_node in filternodes:
         uiname = str(filter_node.findtext('prop[@oor:name="UIName"]/value', namespaces=namespaces))
         apiname = filter_node.attrib['{' + namespaces['oor'] + '}name']
-        
+
         filter_type = str(filter_node.findtext('prop[@oor:name="Type"]/value', namespaces=namespaces))
         type_node = tree.find(
             f'oor:component-data[@oor:name="Types"]/node/node[@oor:name="{filter_type}"]',
@@ -117,14 +123,14 @@ for module in modules:
             extensions = str(type_node.findtext('prop[@oor:name="Extensions"]/value', namespaces=namespaces))
         except AttributeError:
             continue
-        
+
         filter_data = [uiname, apiname, mediatype, extensions]
         print(filter_data)
         filters.append(filter_data)
-    
+
     output += f'\
 <section id="filters{module[:-4]}">\n\
-    <bookmark xml-lang="en-US" branch="index" id="bm_000{module[:-4]}">\n\
+    <bookmark  branch="index" id="bm_000{module[:-4]}">\n\
         <bookmark_value>command line document conversion; filters for {module[:-4].upper()}</bookmark_value>\n\
     </bookmark>\n\
     <h2 id="hd_000{module[:-4]}">Filters for {module[:-4].upper()}</h2>\n\
@@ -156,13 +162,13 @@ for module in modules:
                 <paragraph role="table_font_small paragraph" id="FilterName_{uid}">{item[0]}</paragraph>\n\
             </tablecell>\n\
             <tablecell>\n\
-                <paragraph role="table_font_small paragraph" id="APIName_{uid}" localize="false">{item[1]}</paragraph>\n\
+                <paragraph role="table_font_small paragraph" id="APIName_{uid}" localize="false">&quot;{item[1]}&quot;</paragraph>\n\
             </tablecell>\n\
             <tablecell>\n\
                 <paragraph role="table_font_small paragraph" id="MediaType_{uid}" localize="false">{item[2]} ({item[3]})</paragraph>\n\
             </tablecell>\n\
         </tablerow>\n'
-    
+
     output += f'\
     </table>\n\
 </section>\n'
